package org.jeecg.modules.commonQueryConfig.service.impl;

import org.jeecg.modules.commonQueryConfig.entity.CommonQueryConfig;
import org.jeecg.modules.commonQueryConfig.mapper.CommonQueryConfigMapper;
import org.jeecg.modules.commonQueryConfig.service.ICommonQueryConfigService;
import org.springframework.stereotype.Service;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description: 通用查询配置表
 * @Author: jeecg-boot
 * @Date: 2022-08-20
 * @Version: V1.0
 */
@Service
public class CommonQueryConfigServiceImpl extends ServiceImpl<CommonQueryConfigMapper, CommonQueryConfig> implements ICommonQueryConfigService {

    @Override
    public List<Map<String, Object>> commonQuery(HashMap<String, Object> queryParams) {
        return baseMapper.commonQuery(queryParams);
    }

    @Override
    public List<Map<String, Object>> commonQuery2(HashMap<String, Object> queryParams) {
        return baseMapper.commonQuery2(queryParams);
    }

    @Override
    public List<Map<String, Object>> commonQuery3(HashMap<String, Object> queryParams) {
        return baseMapper.commonQuery3(queryParams);
    }

    @Override
    public List<Map<String, Object>> commonQuery4(HashMap<String, Object> queryParams) {
        return baseMapper.commonQuery4(queryParams);
    }

    @Override
    public List<Map<String, Object>> commonQuery5(HashMap<String, Object> queryParams) {
        return baseMapper.commonQuery5(queryParams);
    }

    @Override
    public List<Map<String, Object>> identifyQuery(HashMap<String, Object> queryParams) {
        return baseMapper.identifyQuery(queryParams);
    }

    @Override
    public List<Map<String, Object>> identifyQuery2(HashMap<String, Object> queryParams) {
        return baseMapper.identifyQuery2(queryParams);
    }

    @Override
    public int count(HashMap<String, Object> queryParams) {
        return baseMapper.count(queryParams);
    }
}
