package org.jeecg.modules.commonQueryConfig.service;

import org.jeecg.modules.commonQueryConfig.entity.CommonQueryConfig;
import com.baomidou.mybatisplus.extension.service.IService;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description: 通用查询配置表
 * @Author: jeecg-boot
 * @Date: 2022-08-20
 * @Version: V1.0
 */
public interface ICommonQueryConfigService extends IService<CommonQueryConfig> {

    List<Map<String, Object>> commonQuery(HashMap<String, Object> queryParams);

    List<Map<String, Object>> commonQuery2(HashMap<String, Object> queryParams);

    List<Map<String, Object>> commonQuery3(HashMap<String, Object> queryParams);

    List<Map<String, Object>> commonQuery4(HashMap<String, Object> queryParams);

    List<Map<String, Object>> commonQuery5(HashMap<String, Object> queryParams);

    List<Map<String, Object>> identifyQuery(HashMap<String, Object> queryParams);

    List<Map<String, Object>> identifyQuery2(HashMap<String, Object> queryParams);

    int count(HashMap<String, Object> queryParams);

}
